<template>
    <!-- 满意度弹窗 -->
    <div>
        <el-dialog title="满意度调查报告" :visible.sync="dialogVisible1" top="10vh" width="60%" :before-close="handleClose">
            <el-upload v-if="!uploadLoading" name="files" class="import-demo" drag :action="url"
                :data="{ bizCode: 'mydandfx', bizId: '', bizType: '' }" :headers="header" :on-success="beforeUpload"
                :before-upload="setLoading" :show-file-list="false">
                <i class="el-icon-upload"></i>
                <div class="el-upload__text">
                    将文件拖到此处，或<em>点击上传</em>
                </div>
            </el-upload>
            <template v-else>
                <el-button v-if="title === '上传'" style="margin-bottom: 15px;" class="updload_btn"
                    @click="removeFile">删除附件</el-button>
                <Docx ref="docx" @closeLoading="closeLoading" :fileUrl="previewUrl"></Docx>
            </template>
            <span slot="footer" class="dialog-footer">
                <template v-if="uploadLoading && this.$route.name === 'SatisfactionSurveys' && title === '上传'">
                    <el-button type="primary" @click="handleSave(1)">保存并上报</el-button>
                    <el-button @click="handleSave(0)">保存为草稿</el-button>
                </template>
                <template v-if="title === '审核' && this.$route.name !== 'SatisfactionSurveys'">
                    <el-button type="primary" @click="handleAudit">通过</el-button>
                    <el-button type="danger" @click="handleReject">驳回</el-button>
                </template>
                <el-button @click="handleClose">取 消</el-button>
            </span>
        </el-dialog>
    </div>
</template>

<script>
import { TableMixin } from '@/mixins/tableMixin'
import sat from '@/api/satisfaction/satisfaction'
import Docx from '@/components/docx'
import req from '@/request.js'
const portal = window.context.portal
export default {
    name: 'reportDialog',
    components: {
        Docx
    },
    mixins: [TableMixin],
    data() {
        return {
            dialogVisible1: false,
            fileId: '',
            uploadLoading: false,
            title: '',
            formData: null,
            loading: true
        }
    },
    created() {
    },
    methods: {
        handleAudit() {
            this.$confirm(`确认审核通过吗？`, this.$t('common.tips'), {
                confirmButtonText: this.$t('common.confirm'),
                cancelButtonText: this.$t('common.cancel'),
                type: 'success',
            }).then(() => {
                let data = {
                    id: this.formData.id,
                    fileStatus: this.$route.name === 'SatisfactionAudits' ? 3 : 5
                }
                sat.auditById(data, res => {
                    if (res.state) {
                        this.$message.success('审核通过成功')
                        this.handleClose()
                        this.$emit('refreshData')
                    }
                })
            })

        },
        handleReject() {
            this.$confirm(`确认审核驳回吗？`, this.$t('common.tips'), {
                confirmButtonText: this.$t('common.confirm'),
                cancelButtonText: this.$t('common.cancel'),
                type: 'error',
            }).then(() => {
                let data = {
                    id: this.formData.id,
                    fileStatus: this.$route.name === 'SatisfactionAudits' ? 2 : 4
                }
                sat.auditById(data, res => {
                    if (res.state) {
                        this.$message.success('审核驳回成功')
                        this.handleClose()
                        this.$emit('refreshData')
                    }
                })
            })

        },
        // 满意度报告
        openDialog(title, id) {
            this.title = title
            let data = this.qs.stringify({
                id,
            })
            sat.queryById(data, res => {
                if (res) {
                    this.formData = res
                    if (this.formData.fileList) {
                        let id = this.formData.fileList.map(item => item.id)
                        this.previewUrl = `${portal}/file/onlinePreviewController/v1/getFileById_${id}`
                        this.uploadLoading = true
                    }
                }
            })
            this.dialogVisible1 = true
        },
        setLoading() {

        },
        beforeUpload(res, file, fileList) {
            if (res.success) {
                let newFile = {
                    ...file,
                    id: file.response.fileId,
                }
                this.formData.fileList = [newFile]
                this.previewUrl = `${portal}/file/onlinePreviewController/v1/getFileById_${newFile.id}`
                this.fileId = newFile.id
                this.uploadLoading = true
                this.$nextTick(() => {
                    this.$refs.docx.initDocx()
                })
                this.$message.success('附件上传成功')
            } else {
                this.$message.error(res.message)
            }
        },
        closeLoading() {

        },
        removeFile() {
            this.$confirm(`确定删除后重新上传吗？`, this.$t('common.tips'), {
                confirmButtonText: this.$t('common.confirm'),
                cancelButtonText: this.$t('common.cancel'),
                type: 'error',
            }).then(() => {
                req.remove(portal + `/file/v1/?ids=${this.fileId}`).then((res) => {
                    console.log(res);
                    if (res.data.state) {
                        this.formData.fileList = []
                        this.$message.success('附件删除成功')
                        this.uploadLoading = false
                    }
                })
            })
        },

        // 文件下载
        handleDownloadFile(file) {
            console.log(file)
            let id = file.fileId
                ? file.fileId
                : file.id
                    ? file.id
                    : file.response.fileId
            window.open(portal + `/file/v1/downloadFile?fileId=${id}`, '_self')
        },

        handleClose() {
            this.formData = null
            this.previewUrl = ''
            this.uploadLoading = false
            this.dialogVisible1 = false
        },

        // 保存为草稿，保存并上报
        handleSave(status) {
            let msg = status ? '上报' : '草稿'
            this.formData.fileStatus = status
            this.formData.ids = this.formData.fileList.map(item => item.id)
            sat.addSurvey(this.formData, res => {
                if (res.state) {
                    this.$message.success(`保存${msg}成功`)
                    this.$emit('refreshData')
                    this.handleClose()
                }
            })
        }
    },
}
</script>

<style lang="scss" scoped>
/deep/.el-dialog__body {
    height: 63vh;
}

@import '~@/assets/css/element-variables.scss';

.common-tree-container {
    height: calc(100% - 70px);
    margin-top: 0.52083vw;
    padding: 1.04167vw 1.04167vw;
    background-color: #fff;
    position: relative;
    box-sizing: border-box;
    overflow-y: auto;
    border-radius: 20px;
    box-shadow: 0px 0px 0.625vw 0 rgba(92, 102, 83, 0.2);
}

.container-head {
    display: flex;
    align-items: center;

    i {
        font-size: 16px;
        margin-left: 5px;
        font-weight: 600;
        cursor: pointer;
    }
}

.move-tree /deep/ .el-tree {
    height: 90%;
    overflow-y: auto;
    border: none;
}

.cloumn-btn {
    border: 1px solid #2761ff;
    padding: 3px 10px;
    border-radius: 5px;

    &:nth-child(1) {
        margin-right: 5px;
    }

    &:nth-child(1):hover {
        background-color: #2761ff;
        color: #fff;
    }

    &:nth-child(2):hover {
        background-color: #2761ff;
        color: #fff;
    }

    /deep/ i,
    span {
        font-size: 16px;
    }
}

/deep/ .el-tree-node__content {
    padding: 5px 0;
}

.del-btn {
    font-weight: bold;
    margin-left: 10px;
    color: $--color-danger;
    cursor: pointer;
}

/deep/ .el-collapse-item__content {
    padding-bottom: 5px;
}

.fs-input {
    /deep/ .el-input__inner {
        height: 29px;
        line-height: 18px;
        text-align: center;
    }
}

.upload_file {
    opacity: 1;
    height: 100%;
    pointer-events: auto;
    // transition: all 0.3s;
}

.upload_file_none {
    opacity: 0;
    height: 0;
    pointer-events: none;
    // transition: all 0.3s;
}

/deep/ .el-upload--picture-card {
    display: block;
    border: none;
    width: 100%;
    height: 70px;
    line-height: 70px;
    text-align: left;
}

/deep/.el-upload-list--picture-card .el-upload-list__item {
    width: 100px;
    height: 70px;
}

/deep/ .upload-demo {
    display: flex;
    flex-direction: column-reverse;
    pointer-events: auto;

    > {
        flex: 1;
    }
}

/deep/ .btn-show {
    .el-upload--picture-card {
        height: 0 !important;
        width: 0;
        opacity: 0;
        pointer-events: none;
    }
}

/deep/.el-descriptions__header {
    margin: 15px 0 0 0;

    .el-descriptions__title {
        font-weight: normal;
    }
}

.file-item {
    display: flex;
    justify-content: space-between;
    width: 100%;
    padding: 5px 3px 5px;
    padding-right: 5px;
    border-radius: 2px;

    a {
        margin-right: 8px;
        user-select: none;
    }
}

.file-item:hover {
    background-color: #f5f5f5;
}

/deep/.el-input__inner::-webkit-outer-spin-button,
/deep/.el-input__inner::-webkit-inner-spin-button {
    -webkit-appearance: none;
}

.satisfaction {
    /deep/.el-table__row {
        .el-table__cell {
            .cell {
                height: 100% !important;
                line-height: 50px !important;
            }
        }
    }
}

/deep/ .el-table th.el-table__cell>.cell {
    white-space: pre;
}

// 导入居中
.import-demo {
    text-align: center;
}
</style>
